Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Generator struct {
Name string
Info interface{} // this structure is not used in config, it is passed to generators
}
Token string
Messages []map[string]interface{}
}
Config is a configuration structure for I1820/lg
type Instance ¶
type Instance struct {
R core.Runner
G generators.Generator
// contains filtered or unexported fields
}
Instance represents a load generator instance. Each instance has a runner with a generator that generates messages. R and G are public and consumers can use their public methods in their advanced use cases.
func NewInstance ¶
NewInstance creates new load generator instance with given configuration
Click to show internal directories.
Click to hide internal directories.